package com.dtn.petro2.petroadmin.bean.transactionbrowser;

import com.dtn.petro2.petro_lib.ElementRow;
import com.dtn.petro2.petro_lib.PetroException;
import com.dtn.petro2.petro_lib.TransactFinder;
import com.dtn.petro2.petro_lib.TransactRow;
import com.dtn.petro2.petroadmin.utils.DataSourceManager;
import org.apache.commons.lang.StringUtils;

import javax.ejb.Remote;
import javax.ejb.Stateless;
import javax.sql.DataSource;
import java.io.IOException;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.*;

@Remote(TransactionBrowserSessionRemote.class)
@Stateless
public class TransactionBrowserBean implements TransactionBrowserSessionRemote {
    private List<TransactRow> transactionResultRows;
    private List<ElementRow> elementResultRows;
    private TransactRow transactRow;
    private ElementRow elementRow;

    public TransactionBrowserBean() {
        elementResultRows = new LinkedList<ElementRow>();
//        transactionResultRows = new LinkedList<TransactRow>();
    }

    public List<TransactRow> doFreeFormSearch(String _currentTransType, Date _transStartDate, String _currentTransStartTime, Date _transEndDate, String _currentTransEndTime, String _currentClientID, String _tbFilter) throws PetroException {
        int intCurrentTransStartTime = Integer.parseInt(_currentTransStartTime);
        int intCurrentTransEndTime = Integer.parseInt(_currentTransEndTime);

        String[] ids = TimeZone.getAvailableIDs(-5 * 60 * 60 * 1000);
        SimpleTimeZone cdt = new SimpleTimeZone(-5 * 60 * 60 * 1000, ids[0]);

        cdt.setStartRule(Calendar.APRIL, 1, Calendar.SUNDAY, 2 * 60 * 60 * 1000);
        cdt.setEndRule(Calendar.OCTOBER, -1, Calendar.SUNDAY, 2 * 60 * 60 * 1000);

        Calendar start = new GregorianCalendar(cdt);
        start.setTime(_transStartDate);
        start.add(Calendar.HOUR_OF_DAY, intCurrentTransStartTime);
        start.add(Calendar.HOUR_OF_DAY, -5);
        long nBgnTime = start.getTimeInMillis();

        Calendar end = new GregorianCalendar(cdt);
        end.setTime(_transEndDate);
        end.add(Calendar.HOUR_OF_DAY, intCurrentTransEndTime);
        end.add(Calendar.HOUR_OF_DAY, -5);
        long nEndTime = end.getTimeInMillis();

        if (nBgnTime > nEndTime) {
            throw new PetroException("End Time value is greater than the Start Time value.");
        } else {
            try {
                DataSource ds = DataSourceManager.getInstance("jdbc/PetroPool").getDataSource();
                Connection con = null;
                try {
                    con = ds.getConnection();

                    TransactFinder tfinder = new TransactFinder(con, _currentTransType, nBgnTime, nEndTime);


                    if (!_currentClientID.equals("0") && !StringUtils.isEmpty(_currentClientID)) {
                        tfinder.setClientKey(_currentClientID);
                    }

                    if (!StringUtils.isEmpty(_tbFilter)) {
                        tfinder.setFileFilter(_tbFilter);
                    }

                    this.transactionResultRows = tfinder.select();

                    if (tfinder.select().size() <= 0) {
                        throw new PetroException("Empty Results.");
                    }

                } catch (SQLException ex) {
                    ex.printStackTrace();
                } catch (IOException ex) {
                    ex.printStackTrace();
                } finally {
                    if (con != null) {
                        con.close();
                    }                    
                }

            } catch (SQLException ex) {
                ex.printStackTrace();
            }
        }
        return this.transactionResultRows;
    }

    public List<TransactRow> doTransactionIdSearch(String _tbTransactID) throws PetroException {
        try {
            DataSource ds = DataSourceManager.getInstance("jdbc/PetroPool").getDataSource();
            Connection con = null;
            try {
                con = ds.getConnection();

                this.transactRow = TransactRow.select(con, _tbTransactID);

                if (this.transactRow == null) {
                    throw new PetroException("Empty Results.");
                }

            } catch (SQLException ex) {
                ex.printStackTrace();
            } finally {
                if (con != null) {
                    con.close();
                }
            }

        } catch (SQLException ex) {
            ex.printStackTrace();
        }

        if(!this.transactionResultRows.add(this.transactRow)){
            throw new PetroException("Invalid Transction.");
        }

        return this.transactionResultRows;
    }

    public List<ElementRow> doElementSearch(String _tbTransactID) throws PetroException {
        try {
            DataSource ds = DataSourceManager.getInstance("jdbc/PetroPool").getDataSource();
            Connection con = null;
            try {
                con = ds.getConnection();

                this.elementRow = ElementRow.select(con, _tbTransactID);

                if (this.elementRow == null) {
                    throw new PetroException("Empty Results.");
                }

            } catch (SQLException ex) {
                ex.printStackTrace();
            } finally {
                if (con != null) {
                    con.close();
                }
            }

        } catch (SQLException ex) {
            ex.printStackTrace();
        }

        if(!this.elementResultRows.add(this.elementRow)){
            throw new PetroException("Invalid Element.");
        }

        return this.elementResultRows;
    }
}
